#--------------------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2008
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program License Agreement.
# See the software licensing materials that came with the IBM XIV Storage System for terms and conditions.
#
#-------------------------------------------------------------------------------------------------------------

import sys
import os
import re

DEFAULT_BANG_LINE = "#!/usr/bin/env xpyv"
PYTHON_BANG_RE = re.compile("#!/(.*)\s?(python|xpyv|xpython)(\s+.+)?$")

def is_unix_script_bang_line(line_string):
    return line_string.startswith("#!/")

def replace_bang_line(script_filename, new_bang_line=DEFAULT_BANG_LINE):
    script_file = file(script_filename)
    first_line = script_file.readline()
    if not is_unix_script_bang_line(first_line):
        return False
    match = PYTHON_BANG_RE.match(first_line)
    if not match:
        return False
    python_arguments = match.groups()[2] or ''
    script_contents = script_file.read()
    script_file.close()
    script_file = file(script_filename, "w")
    script_file.write(new_bang_line + python_arguments + "\n")
    script_file.write(script_contents)
    script_file.close()
    return True

def main():
    if len(sys.argv) < 2:
        sys.stderr.write("Usage: %s [base-path/script-file] <new # line>\n" % sys.argv[0])
        sys.exit(1)
    basepath = sys.argv[1]
    new_bang_line = DEFAULT_BANG_LINE
    if len(sys.argv) > 2:
        new_bang_line = sys.argv[2]
    if not is_unix_script_bang_line(new_bang_line):
        raise RuntimeError("Not a valid bang line: " + new_bang_line)
    success = notscript = 0
    for (dirpath, _, filenames) in os.walk(basepath):
        for filename in filenames:
            if replace_bang_line(os.path.join(dirpath, filename), new_bang_line):
                success += 1
            else:
                notscript += 1
    
    print "Replaces: %d\nNot a script: %d" % (success, notscript)

if __name__ == '__main__':
    main()


